API reference
=============

Modules
-------

.. automodule:: pytorch_spiking.modules

    .. autoautosummary:: pytorch_spiking.modules
        :nosignatures:

Functions
---------

.. automodule:: pytorch_spiking.functional

    .. autoautosummary:: pytorch_spiking.functional
        :nosignatures:
